{% load simple_translation_tags %}

<h1>Entries for {{ day|date:"d F Y" }}</h1>

<ul>
	{% for object in object_list|annotate_with_translations %}
	    {% with object|get_preferred_translation_from_request:request as title %}
		<li><a href="{{ title.get_absolute_url }}">{{ title }} - {{ title.get_language_display }}</a> {{ object|render_language_choices:request|safe }}</li>
	    {% endwith %}
	{% empty %}
		<li>No entries for this day</li>
	{% endfor %}
</ul>