{% load simple_translation_tags %}

<h1>Entries for {{ month|date:"F Y" }}</h1>

{% for object in object_list|annotate_with_translations %}
    {% with object|get_preferred_translation_from_request:request as title %}
	<p>{{ object.pub_date|date:"d b Y" }}<br/><a href="{{ title.get_absolute_url }}">{{ title }}</a> {{ object|render_language_choices:request|safe }}<br/>{{ title.excerpt }}</p>
	{% endwith %}
{% empty %}
	<p>No entries for this month<p>
{% endfor %}