{% load simple_translation_tags %}

<h1>{% with object|get_preferred_translation_from_request:request as title %}{{ title }} - {{ title.get_language_display }}{% endwith %}</h1>

<p class="date"><span>{{ object.pub_date|date:"d F Y" }}</span> {{ object|render_language_choices:request|safe }}</p>
