{% load simple_translation_tags %}

<h1>Entries for {{ year }}</h1>
<ul>
    {% for date in date_list %}
        <li><a href="{% url blog_archive_month year=year month=date|date:'m' %}">{{ date|date:"F" }}</a></li>
    {% empty %}
        <li>No entries for this year</li>
    {% endfor %}
</ul>